==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/LoadBalancerSkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.LoadBalancerSkuName
import com.pulumi.azurenative.network.kotlin.enums.LoadBalancerSkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU of a load balancer.
 * @property name Name of a load balancer SKU.
 * @property tier Tier of a load balancer SKU.
 */
public data class LoadBalancerSkuArgs(
    public val name: Output<Either<String, LoadBalancerSkuName>>? = null,
    public val tier: Output<Either<String, LoadBalancerSkuTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs =
        com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [LoadBalancerSkuArgs].
 */
@PulumiTagMarker
public class LoadBalancerSkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, LoadBalancerSkuName>>? = null

    private var tier: Output<Either<String, LoadBalancerSkuTier>>? = null

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("mihkoapkkjjwucyh")
    public suspend fun name(`value`: Output<Either<String, LoadBalancerSkuName>>) {
        this.name = value
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("smerqjblpemnwtpa")
    public suspend fun tier(`value`: Output<Either<String, LoadBalancerSkuTier>>) {
        this.tier = value
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("ohojttgmbfrlwxgs")
    public suspend fun name(`value`: Either<String, LoadBalancerSkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("xounmjincepbgrdr")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("urxbhsloaephkjdm")
    public fun name(`value`: LoadBalancerSkuName) {
        val toBeMapped = Either.ofRight<String, LoadBalancerSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("ckaumeqfvvpclnle")
    public suspend fun tier(`value`: Either<String, LoadBalancerSkuTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("ovgwiertwpjeqyac")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("qcyatleoyggxubjb")
    public fun tier(`value`: LoadBalancerSkuTier) {
        val toBeMapped = Either.ofRight<String, LoadBalancerSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): LoadBalancerSkuArgs = LoadBalancerSkuArgs(
        name = name,
        tier = tier,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/LoadBalancerSkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.LoadBalancerSkuName
import com.pulumi.azurenative.network.kotlin.enums.LoadBalancerSkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU of a load balancer.
 * @property name Name of a load balancer SKU.
 * @property tier Tier of a load balancer SKU.
 */
public data class LoadBalancerSkuArgs(
    public val name: Output<Either<String, LoadBalancerSkuName>>? = null,
    public val tier: Output<Either<String, LoadBalancerSkuTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs =
        com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [LoadBalancerSkuArgs].
 */
@PulumiTagMarker
public class LoadBalancerSkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, LoadBalancerSkuName>>? = null

    private var tier: Output<Either<String, LoadBalancerSkuTier>>? = null

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("penujtwhdtdjntes")
    public suspend fun name(`value`: Output<Either<String, LoadBalancerSkuName>>) {
        this.name = value
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("klfacvehgmwdfmoh")
    public suspend fun tier(`value`: Output<Either<String, LoadBalancerSkuTier>>) {
        this.tier = value
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("baaktuuwmuqnyvng")
    public suspend fun name(`value`: Either<String, LoadBalancerSkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("slrktqaifdsosulm")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("diiaxucpxqdytnrl")
    public fun name(`value`: LoadBalancerSkuName) {
        val toBeMapped = Either.ofRight<String, LoadBalancerSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("popwhyqtmjsvtmvd")
    public suspend fun tier(`value`: Either<String, LoadBalancerSkuTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("hgtigjcfotdprxyh")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("plvbcrgxanunembm")
    public fun tier(`value`: LoadBalancerSkuTier) {
        val toBeMapped = Either.ofRight<String, LoadBalancerSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): LoadBalancerSkuArgs = LoadBalancerSkuArgs(
        name = name,
        tier = tier,
    )
}
